summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/pcd3311.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/pcd3311.cpp')
-rw-r--r--src/devices/sound/pcd3311.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/devices/sound/pcd3311.cpp b/src/devices/sound/pcd3311.cpp
index d332caa3400..deae4f61062 100644
--- a/src/devices/sound/pcd3311.cpp
+++ b/src/devices/sound/pcd3311.cpp
@@ -48,10 +48,10 @@ void pcd3311_device::device_start()
//-------------------------------------------------
// sound_stream_update - handle update requests for
// our sound stream
//-------------------------------------------------
-void pcd3311_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void pcd3311_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
}
@@ -48,10 +48,10 @@ void pcd3311_device::device_start()
//-------------------------------------------------
-// sound_stream_update - handle update requests for
+// sound_stream_update_legacy - handle update requests for
// our sound stream
//-------------------------------------------------